==> robomaker-0.28.0-sources.jar: software/amazon/awscdk/services/robomaker/CfnRobotApplication.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * @cloudformationResource AWS::RoboMaker::RobotApplication
 * A CloudFormation `AWS::RoboMaker::RobotApplication`
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robotapplication.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.8.2 (build e9eb3c9)", date = "2019-04-04T15:04:22.011Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.robomaker.$Module.class, fqn = "@aws-cdk/aws-robomaker.CfnRobotApplication")
public class CfnRobotApplication extends software.amazon.awscdk.CfnResource {
    protected CfnRobotApplication(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.robomaker.CfnRobotApplication.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::RoboMaker::RobotApplication`.
     * @param scope - scope in which this resource is defined
     * @param id - scoped id of the resource
     * @param props - resource properties
     */
    public CfnRobotApplication(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.robomaker.CfnRobotApplicationProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, java.util.stream.Stream.concat(java.util.stream.Stream.concat(java.util.stream.Stream.of(java.util.Objects.requireNonNull(scope, "scope is required")), java.util.stream.Stream.of(java.util.Objects.requireNonNull(id, "id is required"))), java.util.stream.Stream.of(java.util.Objects.requireNonNull(props, "props is required"))).toArray());
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, java.util.stream.Stream.of(java.util.Objects.requireNonNull(properties, "properties is required")).toArray());
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.robomaker.CfnRobotApplicationProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.robomaker.CfnRobotApplicationProps.class);
    }

    /**
     * @cloudformationAttribute Arn
     */
    public java.lang.String getRobotApplicationArn() {
        return this.jsiiGet("robotApplicationArn", java.lang.String.class);
    }

    /**
     * @cloudformationAttribute CurrentRevisionId
     */
    public java.lang.String getRobotApplicationCurrentRevisionId() {
        return this.jsiiGet("robotApplicationCurrentRevisionId", java.lang.String.class);
    }

    /**
     * The `TagManager` handles setting, removing and formatting tags
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. `Tag` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html
     */
    public static interface RobotSoftwareSuiteProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnRobotApplication.RobotSoftwareSuiteProperty.Name`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-name
         */
        java.lang.String getName();
        /**
         * `CfnRobotApplication.RobotSoftwareSuiteProperty.Version`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-version
         */
        java.lang.String getVersion();

        /**
         * @return a {@link Builder} of {@link RobotSoftwareSuiteProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link RobotSoftwareSuiteProperty}
         */
        final class Builder {
            private java.lang.String _name;
            private java.lang.String _version;

            /**
             * Sets the value of Name
             * @param value `CfnRobotApplication.RobotSoftwareSuiteProperty.Name`
             * @return {@code this}
             */
            public Builder withName(final java.lang.String value) {
                this._name = java.util.Objects.requireNonNull(value, "name is required");
                return this;
            }
            /**
             * Sets the value of Version
             * @param value `CfnRobotApplication.RobotSoftwareSuiteProperty.Version`
             * @return {@code this}
             */
            public Builder withVersion(final java.lang.String value) {
                this._version = java.util.Objects.requireNonNull(value, "version is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link RobotSoftwareSuiteProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public RobotSoftwareSuiteProperty build() {
                return new RobotSoftwareSuiteProperty() {
                    private final java.lang.String $name = java.util.Objects.requireNonNull(_name, "name is required");
                    private final java.lang.String $version = java.util.Objects.requireNonNull(_version, "version is required");

                    @Override
                    public java.lang.String getName() {
                        return this.$name;
                    }

                    @Override
                    public java.lang.String getVersion() {
                        return this.$version;
                    }

                    public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                        com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                        com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                        obj.set("name", om.valueToTree(this.getName()));
                        obj.set("version", om.valueToTree(this.getVersion()));
                        return obj;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnRobotApplication.RobotSoftwareSuiteProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnRobotApplication.RobotSoftwareSuiteProperty.Name`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-name
             */
            @Override
            public java.lang.String getName() {
                return this.jsiiGet("name", java.lang.String.class);
            }

            /**
             * `CfnRobotApplication.RobotSoftwareSuiteProperty.Version`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-version
             */
            @Override
            public java.lang.String getVersion() {
                return this.jsiiGet("version", java.lang.String.class);
            }
        }
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html
     */
    public static interface SourceConfigProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnRobotApplication.SourceConfigProperty.Architecture`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-architecture
         */
        java.lang.String getArchitecture();
        /**
         * `CfnRobotApplication.SourceConfigProperty.S3Bucket`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3bucket
         */
        java.lang.String getS3Bucket();
        /**
         * `CfnRobotApplication.SourceConfigProperty.S3Key`
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3key
         */
        java.lang.String getS3Key();

        /**
         * @return a {@link Builder} of {@link SourceConfigProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link SourceConfigProperty}
         */
        final class Builder {
            private java.lang.String _architecture;
            private java.lang.String _s3Bucket;
            private java.lang.String _s3Key;

            /**
             * Sets the value of Architecture
             * @param value `CfnRobotApplication.SourceConfigProperty.Architecture`
             * @return {@code this}
             */
            public Builder withArchitecture(final java.lang.String value) {
                this._architecture = java.util.Objects.requireNonNull(value, "architecture is required");
                return this;
            }
            /**
             * Sets the value of S3Bucket
             * @param value `CfnRobotApplication.SourceConfigProperty.S3Bucket`
             * @return {@code this}
             */
            public Builder withS3Bucket(final java.lang.String value) {
                this._s3Bucket = java.util.Objects.requireNonNull(value, "s3Bucket is required");
                return this;
            }
            /**
             * Sets the value of S3Key
             * @param value `CfnRobotApplication.SourceConfigProperty.S3Key`
             * @return {@code this}
             */
            public Builder withS3Key(final java.lang.String value) {
                this._s3Key = java.util.Objects.requireNonNull(value, "s3Key is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link SourceConfigProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public SourceConfigProperty build() {
                return new SourceConfigProperty() {
                    private final java.lang.String $architecture = java.util.Objects.requireNonNull(_architecture, "architecture is required");
                    private final java.lang.String $s3Bucket = java.util.Objects.requireNonNull(_s3Bucket, "s3Bucket is required");
                    private final java.lang.String $s3Key = java.util.Objects.requireNonNull(_s3Key, "s3Key is required");

                    @Override
                    public java.lang.String getArchitecture() {
                        return this.$architecture;
                    }

                    @Override
                    public java.lang.String getS3Bucket() {
                        return this.$s3Bucket;
                    }

                    @Override
                    public java.lang.String getS3Key() {
                        return this.$s3Key;
                    }

                    public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                        com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                        com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                        obj.set("architecture", om.valueToTree(this.getArchitecture()));
                        obj.set("s3Bucket", om.valueToTree(this.getS3Bucket()));
                        obj.set("s3Key", om.valueToTree(this.getS3Key()));
                        return obj;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnRobotApplication.SourceConfigProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnRobotApplication.SourceConfigProperty.Architecture`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-architecture
             */
            @Override
            public java.lang.String getArchitecture() {
                return this.jsiiGet("architecture", java.lang.String.class);
            }

            /**
             * `CfnRobotApplication.SourceConfigProperty.S3Bucket`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3bucket
             */
            @Override
            public java.lang.String getS3Bucket() {
                return this.jsiiGet("s3Bucket", java.lang.String.class);
            }

            /**
             * `CfnRobotApplication.SourceConfigProperty.S3Key`
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3key
             */
            @Override
            public java.lang.String getS3Key() {
                return this.jsiiGet("s3Key", java.lang.String.class);
            }
        }
    }
}

==> robomaker-0.29.0-sources.jar: software/amazon/awscdk/services/robomaker/CfnRobotApplication.java <==
package software.amazon.awscdk.services.robomaker;

/**
 * A CloudFormation `AWS::RoboMaker::RobotApplication`.
 * 
 * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-robomaker-robotapplication.html
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.10.3 (build 6bbf743)", date = "2019-04-24T21:02:53.135Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.robomaker.$Module.class, fqn = "@aws-cdk/aws-robomaker.CfnRobotApplication")
public class CfnRobotApplication extends software.amazon.awscdk.CfnResource {
    protected CfnRobotApplication(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
        super(mode);
    }
    static {
        RESOURCE_TYPE_NAME = software.amazon.jsii.JsiiObject.jsiiStaticGet(software.amazon.awscdk.services.robomaker.CfnRobotApplication.class, "resourceTypeName", java.lang.String.class);
    }
    /**
     * Create a new `AWS::RoboMaker::RobotApplication`.
     * 
     * @param scope - scope in which this resource is defined.
     * @param id - scoped id of the resource.
     * @param props - resource properties.
     */
    public CfnRobotApplication(final software.amazon.awscdk.Construct scope, final java.lang.String id, final software.amazon.awscdk.services.robomaker.CfnRobotApplicationProps props) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.Jsii);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(scope, "scope is required"), java.util.Objects.requireNonNull(id, "id is required"), java.util.Objects.requireNonNull(props, "props is required") });
    }

    @Override
    protected java.util.Map<java.lang.String, java.lang.Object> renderProperties(@javax.annotation.Nullable final java.lang.Object properties) {
        return this.jsiiCall("renderProperties", java.util.Map.class, new Object[] { properties });
    }
    /**
     * The CloudFormation resource type name for this resource class.
     */
    public final static java.lang.String RESOURCE_TYPE_NAME;

    public software.amazon.awscdk.services.robomaker.CfnRobotApplicationProps getPropertyOverrides() {
        return this.jsiiGet("propertyOverrides", software.amazon.awscdk.services.robomaker.CfnRobotApplicationProps.class);
    }

    /**
     */
    public java.lang.String getRobotApplicationArn() {
        return this.jsiiGet("robotApplicationArn", java.lang.String.class);
    }

    /**
     */
    public java.lang.String getRobotApplicationCurrentRevisionId() {
        return this.jsiiGet("robotApplicationCurrentRevisionId", java.lang.String.class);
    }

    /**
     * The `TagManager` handles setting, removing and formatting tags.
     * 
     * Tags should be managed either passing them as properties during
     * initiation or by calling methods on this object. If both techniques are
     * used only the tags from the TagManager will be used. `Tag` (aspect)
     * will use the manager.
     */
    public software.amazon.awscdk.TagManager getTags() {
        return this.jsiiGet("tags", software.amazon.awscdk.TagManager.class);
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html
     */
    public static interface RobotSoftwareSuiteProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnRobotApplication.RobotSoftwareSuiteProperty.Name`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-name
         */
        java.lang.String getName();
        /**
         * `CfnRobotApplication.RobotSoftwareSuiteProperty.Version`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-version
         */
        java.lang.String getVersion();

        /**
         * @return a {@link Builder} of {@link RobotSoftwareSuiteProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link RobotSoftwareSuiteProperty}
         */
        final class Builder {
            private java.lang.String _name;
            private java.lang.String _version;

            /**
             * Sets the value of Name
             * @param value `CfnRobotApplication.RobotSoftwareSuiteProperty.Name`.
             * @return {@code this}
             */
            public Builder withName(final java.lang.String value) {
                this._name = java.util.Objects.requireNonNull(value, "name is required");
                return this;
            }
            /**
             * Sets the value of Version
             * @param value `CfnRobotApplication.RobotSoftwareSuiteProperty.Version`.
             * @return {@code this}
             */
            public Builder withVersion(final java.lang.String value) {
                this._version = java.util.Objects.requireNonNull(value, "version is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link RobotSoftwareSuiteProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public RobotSoftwareSuiteProperty build() {
                return new RobotSoftwareSuiteProperty() {
                    private final java.lang.String $name = java.util.Objects.requireNonNull(_name, "name is required");
                    private final java.lang.String $version = java.util.Objects.requireNonNull(_version, "version is required");

                    @Override
                    public java.lang.String getName() {
                        return this.$name;
                    }

                    @Override
                    public java.lang.String getVersion() {
                        return this.$version;
                    }

                    public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                        com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                        com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                        obj.set("name", om.valueToTree(this.getName()));
                        obj.set("version", om.valueToTree(this.getVersion()));
                        return obj;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnRobotApplication.RobotSoftwareSuiteProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnRobotApplication.RobotSoftwareSuiteProperty.Name`.
             * 
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-name
             */
            @Override
            public java.lang.String getName() {
                return this.jsiiGet("name", java.lang.String.class);
            }

            /**
             * `CfnRobotApplication.RobotSoftwareSuiteProperty.Version`.
             * 
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-robotsoftwaresuite.html#cfn-robomaker-robotapplication-robotsoftwaresuite-version
             */
            @Override
            public java.lang.String getVersion() {
                return this.jsiiGet("version", java.lang.String.class);
            }
        }
    }
    /**
     * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html
     */
    public static interface SourceConfigProperty extends software.amazon.jsii.JsiiSerializable {
        /**
         * `CfnRobotApplication.SourceConfigProperty.Architecture`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-architecture
         */
        java.lang.String getArchitecture();
        /**
         * `CfnRobotApplication.SourceConfigProperty.S3Bucket`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3bucket
         */
        java.lang.String getS3Bucket();
        /**
         * `CfnRobotApplication.SourceConfigProperty.S3Key`.
         * 
         * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3key
         */
        java.lang.String getS3Key();

        /**
         * @return a {@link Builder} of {@link SourceConfigProperty}
         */
        static Builder builder() {
            return new Builder();
        }

        /**
         * A builder for {@link SourceConfigProperty}
         */
        final class Builder {
            private java.lang.String _architecture;
            private java.lang.String _s3Bucket;
            private java.lang.String _s3Key;

            /**
             * Sets the value of Architecture
             * @param value `CfnRobotApplication.SourceConfigProperty.Architecture`.
             * @return {@code this}
             */
            public Builder withArchitecture(final java.lang.String value) {
                this._architecture = java.util.Objects.requireNonNull(value, "architecture is required");
                return this;
            }
            /**
             * Sets the value of S3Bucket
             * @param value `CfnRobotApplication.SourceConfigProperty.S3Bucket`.
             * @return {@code this}
             */
            public Builder withS3Bucket(final java.lang.String value) {
                this._s3Bucket = java.util.Objects.requireNonNull(value, "s3Bucket is required");
                return this;
            }
            /**
             * Sets the value of S3Key
             * @param value `CfnRobotApplication.SourceConfigProperty.S3Key`.
             * @return {@code this}
             */
            public Builder withS3Key(final java.lang.String value) {
                this._s3Key = java.util.Objects.requireNonNull(value, "s3Key is required");
                return this;
            }

            /**
             * Builds the configured instance.
             * @return a new instance of {@link SourceConfigProperty}
             * @throws NullPointerException if any required attribute was not provided
             */
            public SourceConfigProperty build() {
                return new SourceConfigProperty() {
                    private final java.lang.String $architecture = java.util.Objects.requireNonNull(_architecture, "architecture is required");
                    private final java.lang.String $s3Bucket = java.util.Objects.requireNonNull(_s3Bucket, "s3Bucket is required");
                    private final java.lang.String $s3Key = java.util.Objects.requireNonNull(_s3Key, "s3Key is required");

                    @Override
                    public java.lang.String getArchitecture() {
                        return this.$architecture;
                    }

                    @Override
                    public java.lang.String getS3Bucket() {
                        return this.$s3Bucket;
                    }

                    @Override
                    public java.lang.String getS3Key() {
                        return this.$s3Key;
                    }

                    public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
                        com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
                        com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
                        obj.set("architecture", om.valueToTree(this.getArchitecture()));
                        obj.set("s3Bucket", om.valueToTree(this.getS3Bucket()));
                        obj.set("s3Key", om.valueToTree(this.getS3Key()));
                        return obj;
                    }

                };
            }
        }

        /**
         * A proxy class which represents a concrete javascript instance of this type.
         */
        final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.robomaker.CfnRobotApplication.SourceConfigProperty {
            protected Jsii$Proxy(final software.amazon.jsii.JsiiObject.InitializationMode mode) {
                super(mode);
            }

            /**
             * `CfnRobotApplication.SourceConfigProperty.Architecture`.
             * 
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-architecture
             */
            @Override
            public java.lang.String getArchitecture() {
                return this.jsiiGet("architecture", java.lang.String.class);
            }

            /**
             * `CfnRobotApplication.SourceConfigProperty.S3Bucket`.
             * 
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3bucket
             */
            @Override
            public java.lang.String getS3Bucket() {
                return this.jsiiGet("s3Bucket", java.lang.String.class);
            }

            /**
             * `CfnRobotApplication.SourceConfigProperty.S3Key`.
             * 
             * @see http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-robomaker-robotapplication-sourceconfig.html#cfn-robomaker-robotapplication-sourceconfig-s3key
             */
            @Override
            public java.lang.String getS3Key() {
                return this.jsiiGet("s3Key", java.lang.String.class);
            }
        }
    }
}
